/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.rcp.application;

import static org.fortiss.af3.rcp.application.advisors.ApplicationActionBarAdvisor.getNewAF3LibraryAction;
import static org.fortiss.af3.rcp.application.advisors.ApplicationActionBarAdvisor.getNewAF3ProjectAction;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.ActionContributionItem;
import org.eclipse.jface.action.IContributionItem;
import org.fortiss.tooling.kernel.ui.extension.IContextMenuContributor;
import org.fortiss.tooling.kernel.ui.extension.data.ContextMenuContextProvider;
import org.fortiss.tooling.kernel.ui.service.IContextMenuService;
import org.fortiss.tooling.kernel.ui.service.INavigatorService;

/**
 * Context menu contributions to include new project action.
 * 
 * @author becker
 */
public class NewProjectContextMenu implements IContextMenuContributor {

	/** {@inheritDoc} */
	@Override
	public List<IContributionItem> getContributedItems(EObject selection,
			ContextMenuContextProvider contextProvider) {
		// if the user right-clicks in an empty area (no selection)
		if(selection == null && INavigatorService.getInstance().isNavigatorView(contextProvider) &&
				getNewAF3ProjectAction() != null && getNewAF3LibraryAction() != null) {
			// add possibility to create new projects to context menu
			List<IContributionItem> contributionItems = new ArrayList<IContributionItem>();
			contributionItems.add(new ActionContributionItem(getNewAF3ProjectAction()));
			contributionItems.add(new ActionContributionItem(getNewAF3LibraryAction()));
			return contributionItems;
		}
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public String getMenuSectionID() {
		return IContextMenuService.TOP_MOST_MENU_SECTION_ID;
	}
}
